Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/display_button_simpletest.py
    :caption: examples/display_button_simpletest.py
    :linenos:

Button Color Properties
-----------------------

Demonstrate the different color possibilities present in the library

.. literalinclude:: ../examples/display_button_color_properties.py
    :caption: examples/display_button_color_properties.py
    :linenos:

Button Custom Font
------------------

Shows how to use different fonts with your button

.. literalinclude:: ../examples/display_button_customfont.py
    :caption: examples/display_button_customfont.py
    :linenos:

Soundboard
----------

A soundboard made with buttons

.. literalinclude:: ../examples/display_button_soundboard.py
    :caption: examples/display_button_soundboard.py
    :linenos:
